
#include "itkGaussianImageSource.h"
#include "itkImageSpatialObject2.h"
#include "itkImageSpatialObject.h"
#include "vnl/vnl_math.h"


//-------------------------------------------------------------------------------------

int main( int argc, char *argv[] )
{  
  const unsigned int Dimension = 2;
  const unsigned int imSize = 100;
  typedef unsigned char PixelType;
  typedef double CoordRepType;
  
  typedef itk::Image< PixelType, Dimension >      ImageType;  
  typedef itk::GaussianImageSource<ImageType>     ImageSourceType;
  typedef itk::ImageSpatialObject< Dimension, PixelType> ImageSpatialObjectType;
  typedef itk::ImageSpatialObject2< Dimension, PixelType> ImageSpatialObjectType2;
  typedef ImageSpatialObjectType::BoundingBoxType BoundingBoxType;

  typedef ImageType::DirectionType DirectionType;
  typedef ImageType::RegionType RegionType;
  typedef ImageType::SizeType SizeType;
  typedef ImageType::IndexType IndexType;
  typedef ImageType::SpacingType SpacingType;
  typedef ImageType::PointType OriginType;

  /** Create gauss image */
  ImageSourceType::Pointer imageSource = ImageSourceType::New();
  ImageType::Pointer image = 0;
  SizeType imageSize;
  imageSize.Fill( imSize );
  imageSource->SetSize( imageSize );
  DirectionType dircos;
  dircos.SetIdentity();

  /** rotated direction cosines */
  const double factor = 1.0;
  dircos(0,0)= vcl_cos( factor*vnl_math::pi_over_4 );
  dircos(0,1)= -vcl_sin( factor*vnl_math::pi_over_4 );
  dircos(1,0)= vcl_sin( factor*vnl_math::pi_over_4 );
  dircos(1,1)= vcl_cos( factor*vnl_math::pi_over_4 );

  imageSource->SetDirection( dircos );
  try
  {    
    imageSource->Update();
  }
  catch ( itk::ExceptionObject & excp )
  {
    std::cerr << excp << std::endl;
    return 1;
  }  
  image = imageSource->GetOutput();

  /** Create spatial object */
  ImageSpatialObjectType::Pointer spat = ImageSpatialObjectType::New();
  spat->SetImage( image );
  spat->ComputeBoundingBox();
  BoundingBoxType::Pointer bb = spat->GetBoundingBox();

  std::cout << "ITK:" << std::endl;
  std::cout << "min: " << bb->GetMinimum() << std::endl;
  std::cout << "max: " << bb->GetMaximum() << std::endl;

  /** Create spatial object2 */
  ImageSpatialObjectType2::Pointer spat2 = ImageSpatialObjectType2::New();
  spat2->SetImage( image );
  spat2->ComputeBoundingBox();
  BoundingBoxType::Pointer bb2 = spat2->GetBoundingBox();

  std::cout << "FIX:" << std::endl;
  std::cout << "min: " << bb2->GetMinimum() << std::endl;
  std::cout << "max: " << bb2->GetMaximum() << std::endl;


  /** Return a value. */
  return 0;

} // end main


